#!/usr/bin/env python
# -*- encoding: utf-8 -*-
'''
@File    :   config.py    
@Contact :   wangcc@csc.com.cn
@License :   (C)Copyright 2017-2018, CSC

@Modify Time      @Author    @Version    @Desciption
------------      -------    --------    -----------
2021/11/3 13:35   wangcc     1.0         None
'''


# pctchange limit
up_bound_r = 0.095
dn_bound_r = -0.095
dnlimit=0.025
uplimit=0.975
defualt_numna = 10
markets = ["all", "zz500", "zz800", "hs300", "zz1000", "top2500"]
ins_sample_date_str = "2014-01-01"
